@@ -43,7 +43,8 @@ class SubscriptionManager:
         if user_agent is not None:
             self._user_agent = user_agent
         else:
-            self._user_agent = "Python/{0[0]}.{0[1]}".format(sys.version_info)
+            _ver = sys.version_info
+            self._user_agent = f"Python/{_ver[0]}.{_ver[1]}"
         self._user_agent += f" graphql-subscription-manager/{VERSION}"
 
     def start(self):
@@ -78,13 +79,27 @@ class SubscriptionManager:
             self.retry()
             return
 
-        try:
-            await self._running_loop()
-        except Exception:  # pylint: disable=broad-except
-            if self._state == STATE_STOPPED:
-                _LOGGER.debug("Stopped, Connection error", exc_info=True)
+        k = 0
+        while self._state in (
+                STATE_RUNNING,
+                STATE_STARTING,
+        ):
+            try:
+                msg = await asyncio.wait_for(self.websocket.recv(), timeout=60)
+            except asyncio.TimeoutError:
+                k += 1
+                if k > 10:
+                    _LOGGER.debug("No data, reconnecting.")
+                    self.retry()
+                    return
+                _LOGGER.debug("No websocket data, sending a ping.")
+                await asyncio.wait_for(await self.websocket.ping(), timeout=20)
+            except Exception:  # pylint: disable=broad-except
+                if self._state == STATE_RUNNING:
+                    self.retry()
             else:
-                self.retry()
+                k = 0
+                self._process_msg(msg)
 
     async def stop(self):
         """Close websocket connection."""
@@ -219,23 +234,3 @@ class SubscriptionManager:
                 }
             )
         )
-
-    async def _running_loop(self):
-        k = 0
-        while self._state in (
-            STATE_RUNNING,
-            STATE_STARTING,
-        ):
-            try:
-                msg = await asyncio.wait_for(self.websocket.recv(), timeout=60)
-            except asyncio.TimeoutError:
-                k += 1
-                if k > 5:
-                    _LOGGER.debug("No data, reconnecting.")
-                    self.retry()
-                    return
-                _LOGGER.debug("No websocket data, sending a ping.")
-                await asyncio.wait_for(await self.websocket.ping(), timeout=3)
-            else:
-                k = 0
-                self._process_msg(msg)
